<?php

/* protected */
if (!defined('ABSPATH'))
	exit;

/**
 * Wf_Cart_Output
 * Class for outputing cart
 *
 * @since [1.0]
 *
 * @return html
 */
class Wf_Cart_Output{
	
	function __construct()
	{
		add_action( 'get_cart_contents',array( $this,'wf_cart_contents' ), 10, 1 );
		add_action( 'show_cart_output', array( $this,'floating_cart_output' ), 10, 1);
	}

	/**
	* function to output cart html
	*
	* @since  [1.0]
	*/		
	public function floating_cart_output( $value='' ){ ?>
	<div class="cart-cont">
		<div class="prepend-cart">
			<?php do_action('get_cart_contents');?></div>
			<div class='cart-icon'><i class="fa fa-shopping-cart" aria-hidden="true"></i>
				<div class='item-count'>
					<span class="total-item">
						<?php if ( ! WC()->cart->is_empty() ){
							echo WC()->cart->get_cart_contents_count();
						}
						?>
					</span>
				</div>
			</div>
		</div>

	</div>

	<?php
}

    /**
    * Get all cart Contents
    *
    * @since  [1.0]
    *
    * @param  output
    */		
    public function wf_cart_contents($value=''){
    	?>
    	<div class="cart-header">Cart</div>
    	<div class="wf-floating-cart-container">
    		<i class="fa fa-times close-floating-cart" aria-hidden="true"></i>
    		<ul class="cart_list product_list_widget">
    			<?php if ( ! WC()->cart->is_empty() ) :

    			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
    				$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
    				$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

    				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
    					$product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key );
    					$thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
    					$product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
    					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
    					?>
    					<li class="<?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
    						<?php
    						echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
    							'<a href="%s" class="remove" title="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
    							esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
    							__( 'Remove this item', 'woocommerce' ),
    							esc_attr( $product_id ),
    							esc_attr( $_product->get_sku() )
    							), $cart_item_key );
    							?>
    							<?php if ( ! $_product->is_visible() ) : ?>
    								<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) . $product_name . '&nbsp;'; ?>
    							<?php else : ?>
    								<a href="<?php echo esc_url( $product_permalink ); ?>">
    									<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) . $product_name . '&nbsp;'; ?>
    								</a>
    							<?php endif; ?>
    							<?php echo WC()->cart->get_item_data( $cart_item ); ?>

    							<?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>
    						</li>
    						<?php
    					}
    				}
    				?>

    			<?php else : ?>

    				<li class="empty"><?php _e( 'No products in the cart.', 'woocommerce' ); ?></li>

    			<?php endif; ?>


    		</ul><!-- end product list -->

    		<?php if ( ! WC()->cart->is_empty() ) : ?>

    			<p class="total"><strong><?php _e( 'Total', 'woocommerce' ); ?>:</strong> <?php //wc_cart_totals_order_total_html();
    			echo WC()->cart->get_cart_total(); ?></p>

    			<?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

    			<p class="buttons">
    				<a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="button wc-forward"><?php _e( 'View Cart', 'woocommerce' ); ?></a>
    				<a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="button checkout wc-forward"><?php _e( 'Checkout', 'woocommerce' ); ?></a>
    			</p>

    		<?php endif;?>
    	</div>
    	<?php
    }
}

new Wf_Cart_Output();